@@ -1,6 +1,6 @@
 #' Normalize GUID and tenant values
 #'
-#' These functions are used by `get_azure_token` to recognise and properly format tenant and app IDs.
+#' These functions are used by `get_azure_token` to recognise and properly format tenant and app IDs. `is_guid` can also be used generically for identifying GUIDs/UUIDs in any context.
 #'
 #' @param tenant For `normalize_tenant`, a string containing an Azure Active Directory tenant. This can be a name ("myaadtenant"), a fully qualified domain name ("myaadtenant.onmicrosoft.com" or "mycompanyname.com"), or a valid GUID.
 #' @param x For `is_guid`, a character string; for `normalize_guid`, a string containing a _validly formatted_ GUID.
@@ -12,14 +12,14 @@
 #' 3. Otherwise, if it is not the string "common", append ".onmicrosoft.com" to it
 #' 4. Otherwise, return the value of `tenant`
 #'
-#' See the link below for GUID formats recognised by these functions.
+#' These functions are vectorised. See the link below for the GUID formats they accept.
 #'
 #' @return
-#' For `is_guid`, whether the argument is a validly formatted GUID.
+#' For `is_guid`, a logical vector indicating which values of `x` are validly formatted GUIDs.
 #'
-#' For `normalize_guid`, the GUID in canonical format. If the argument is not recognised as a GUID, it throws an error.
+#' For `normalize_guid`, a vector of GUIDs in canonical format. If any values of `x` are not recognised as GUIDs, it throws an error.
 #'
-#' For `normalize_tenant`, the normalized ID or name of the tenant.
+#' For `normalize_tenant`, the normalized tenant IDs or names.
 #'
 #' @seealso
 #' [get_azure_token]
@@ -43,6 +43,12 @@
 #' normalize_tenant("microsoft.com") # returns 'microsoft.com'
 #' normalize_tenant("72f988bf-86f1-41af-91ab-2d7cd011db47") # returns the GUID
 #'
+#' # vector arguments are accepted
+#' ids <- c("72f988bf-86f1-41af-91ab-2d7cd011db47", "72f988bf86f141af91ab2d7cd011db47")
+#' is_guid(ids)
+#' normalize_guid(ids)
+#' normalize_tenant(c("microsoft", ids))
+#'
 #' @export
 #' @rdname guid
 normalize_tenant <- function(tenant)
@@ -54,11 +60,12 @@ normalize_tenant <- function(tenant)
 
     # check if supplied a guid; if not, check if a fqdn;
     # if not, check if 'common'; if not, append '.onmicrosoft.com'
-    if(is_guid(tenant))
-        return(normalize_guid(tenant))
+    guid <- is_guid(tenant)
+    tenant[guid] <- normalize_guid(tenant[guid])
+
+    name <- !guid & (tenant != "common") & !grepl(".", tenant, fixed=TRUE)
+    tenant[name] <- paste0(tenant[name], ".onmicrosoft.com")
 
-    if(!grepl("\\.", tenant) && tenant != "common")
-        tenant <- paste(tenant, "onmicrosoft.com", sep=".")
     tenant
 }
 
@@ -67,7 +74,7 @@ normalize_tenant <- function(tenant)
 #' @rdname guid
 normalize_guid <- function(x)
 {
-    if(!is_guid(x))
+    if(!all(is_guid(x)))
         stop("Not a GUID", call.=FALSE)
 
     x <- sub("^[({]?([-0-9a-f]+)[})]$", "\\1", x)
@@ -85,9 +92,13 @@ normalize_guid <- function(x)
 #' @rdname guid
 is_guid <- function(x)
 {
-    grepl("^[0-9a-f]{32}$", x) ||
-    grepl("^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$", x) ||
-    grepl("^\\{[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}}$", x) ||
+    if(!is.character(x))
+        return(FALSE)
+    x <- tolower(x)
+
+    grepl("^[0-9a-f]{32}$", x) |
+    grepl("^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$", x) |
+    grepl("^\\{[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}}$", x) |
     grepl("^\\([0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\\)$", x)
 }
 
